@@ -3,7 +3,7 @@
 ##                                                                          ##
 ##          MATLAB Independent, Small & Safe, High Integrity Tools          ##
 ##                                                                          ##
-##              Copyright (C) 2020, Florian Schanda                         ##
+##              Copyright (C) 2020-2021, Florian Schanda                    ##
 ##                                                                          ##
 ##  This file is part of MISS_HIT.                                          ##
 ##                                                                          ##
@@ -23,7 +23,7 @@
 ##                                                                          ##
 ##############################################################################
 
-from copy import copy
+from copy import deepcopy
 
 
 ##############################################################################
@@ -45,7 +45,7 @@ class Config:
             # All rules are enabled
 
             self.style_config = {
-                cfg_name: copy(STYLE_CONFIGURATION[cfg_name].default)
+                cfg_name: deepcopy(STYLE_CONFIGURATION[cfg_name].default)
                 for cfg_name in STYLE_CONFIGURATION
             }
             # All rule configuration is default
@@ -62,10 +62,10 @@ class Config:
             self.enabled         = other.enabled
             self.octave          = other.octave
             self.pragmas         = other.pragmas
-            self.style_rules     = copy(other.style_rules)
-            self.style_config    = copy(other.style_config)
-            self.enabled_metrics = copy(other.enabled_metrics)
-            self.metric_limits   = copy(other.metric_limits)
+            self.style_rules     = deepcopy(other.style_rules)
+            self.style_config    = deepcopy(other.style_config)
+            self.enabled_metrics = deepcopy(other.enabled_metrics)
+            self.metric_limits   = deepcopy(other.metric_limits)
 
     def dump(self, indent=0):
         items = ["MH Configuration object"]
@@ -179,6 +179,10 @@ class Regex_Style_Configuration(String_Style_Configuration):
     pass
 
 
+class Copyright_Regex_Style_Configuration(Regex_Style_Configuration):
+    pass
+
+
 class Encoding_Style_Configuration(String_Style_Configuration):
     pass
 
@@ -251,8 +255,18 @@ STYLE_RULES = {
     "copyright_notice" : Style_Rule(
         "Ensures the first thing in each file is a copyright notice.",
         {
+            "copyright_regex": Copyright_Regex_Style_Configuration(
+                ("Regex for picking out copyright notice. Must include "
+                 "named groups: 'ystart', 'yend', and 'org'"),
+                default = (r"(\(c\) )?Copyright "
+                           r"((?P<ystart>\d\d\d\d)(-| - ))?(?P<yend>\d\d\d\d)"
+                           r"( by)? *(?P<org>.*)")),
             "copyright_entity": Set_Style_Configuration(
                 "Valid copyright holder."),
+            "copyright_primary_entity": String_Style_Configuration(
+                "Valid primary copyright holder."),
+            "copyright_3rd_party_entity": Set_Style_Configuration(
+                "Recognised 3rd-party copyright holder."),
             "copyright_in_embedded_code": Boolean_Style_Configuration(
                 ("Enforce copyright statements in code embedded in Simulink"
                  " models."),
