@@ -3,7 +3,7 @@
 ##                                                                          ##
 ##          MATLAB Independent, Small & Safe, High Integrity Tools          ##
 ##                                                                          ##
-##              Copyright (C) 2019-2020, Florian Schanda                    ##
+##              Copyright (C) 2019-2021, Florian Schanda                    ##
 ##              Copyright (C) 2019-2020, Zenuity AB                         ##
 ##                                                                          ##
 ##  This file is part of MISS_HIT.                                          ##
@@ -46,9 +46,6 @@ from miss_hit_core.m_lexer import MATLAB_Lexer, Token_Buffer
 from miss_hit_core.m_parser import MATLAB_Parser
 
 
-COPYRIGHT_REGEX = r"(\(c\) )?Copyright (\d\d\d\d-)?\d\d\d\d( by)? *(?P<org>.*)"
-
-
 class Style_Rule(metaclass=ABCMeta):
     def __init__(self, name, autofix):
         assert isinstance(name, str)
@@ -348,16 +345,21 @@ KEYWORDS_WITH_WS = frozenset([
 ])
 
 
-def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
+def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed, valid_code):
     assert isinstance(mh, Message_Handler)
     assert isinstance(tbuf, Token_Buffer)
     assert isinstance(is_embedded, bool)
     assert isinstance(fixed, bool)
+    assert isinstance(valid_code, bool)
 
     in_copyright_notice = (cfg.active("copyright_notice") and
                            (not is_embedded or
                             cfg.style_config["copyright_in_embedded_code"]))
-    entities = cfg.style_config["copyright_entity"]
+    entities = (cfg.style_config["copyright_entity"] |
+                cfg.style_config["copyright_3rd_party_entity"])
+    if cfg.style_config["copyright_primary_entity"]:
+        entities.add(cfg.style_config["copyright_primary_entity"])
+    copyright_regex = cfg.style_config["copyright_regex"]
     company_copyright_found = False
     generic_copyright_found = False
     copyright_token = None
@@ -415,7 +417,7 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
 
         # Keep track of statement starters. This is required for
         # indentation.
-        if token.first_in_statement:
+        if valid_code and token.first_in_statement:
             # We need to take special care of comments that are the
             # first thing after an open block. Since comments are not
             # attached to the AST (and it is not practical to do so),
@@ -452,7 +454,7 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
         # Corresponds to the old CodeChecker CopyrightCheck rule
         if in_copyright_notice:
             if token.kind == "COMMENT":
-                match = re.search(COPYRIGHT_REGEX, token.value)
+                match = re.search(copyright_regex, token.value)
                 if match:
                     # We have a sane copyright string
                     copyright_token = token
@@ -491,10 +493,15 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
                     # If we have something basic, we only raise an
                     # issue if we're supposed to have something
                     # specific.
-                    if entities:
+                    if len(entities) == 1:
                         mh.style_issue(copyright_token.location,
-                                       "Copyright does not mention one of %s" %
-                                       (" or ".join(entities)))
+                                       "Copyright does not mention %s" %
+                                       list(entities)[0])
+                    elif len(entities) > 1:
+                        mh.style_issue(copyright_token.location,
+                                       "Copyright does not mention one of %s"
+                                       % " or ".join(entities))
+
                 elif copyright_token:
                     # We found something that might be a copyright,
                     # but is not in a sane format
@@ -649,7 +656,8 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
                                    fixed)
 
             # Make sure we have whitespace _after_ the function end
-            elif token.value == "end" and \
+            elif valid_code and \
+                 token.value == "end" and \
                  cfg.active("whitespace_around_functions") and \
                  isinstance(token.ast_link, Function_Definition):
                 # We first need to find the actual last token on this line
@@ -817,7 +825,8 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
                         token.fix.ensure_ws_before = True
                         token.fix.ensure_ws_after = True
 
-            if cfg.active("implicit_shortcircuit") and \
+            if valid_code and \
+               cfg.active("implicit_shortcircuit") and \
                token.value in ("&", "|") and \
                token.ast_link and \
                isinstance(token.ast_link, Binary_Logical_Operation) and \
@@ -871,7 +880,9 @@ def stage_3_analysis(mh, cfg, tbuf, is_embedded, fixed):
                            fixed and continuation_is_fixed)
 
         # Complain about indentation
-        if cfg.active("indentation") and token.kind != "NEWLINE":
+        if valid_code and \
+           cfg.active("indentation") and \
+           token.kind != "NEWLINE":
             if token.first_in_line and not token.block_comment:
                 if token.first_in_statement:
                     if token.ast_link:
@@ -1070,7 +1081,8 @@ class MH_Style(command_line.MISS_HIT_Back_End):
             cfg         = wp.cfg,
             tbuf        = tbuf,
             is_embedded = isinstance(wp, work_package.Embedded_MATLAB_WP),
-            fixed       = parse_tree is not None)
+            fixed       = parse_tree is not None,
+            valid_code  = parse_tree is not None)
 
         # Stage 4 - rules involving the parse tree
 
